package CoupledClutches "Example package studing the effect of four inertias separated by clutches."
  model CoupledClutchesModel "Example studing the effect of four inertias separated by clutches."
    extends Modelica.Icons.Example;
    parameter Modelica.Units.SI.Time T1 = 15 "Time when clutch1 is disengaged";
    parameter Modelica.Units.SI.Time T2 = 5 "Time when clutch2 is invoked";
    parameter Modelica.Units.SI.Time T3 = 10 "Time when clutch3 is invoked";
    parameter Modelica.Units.SI.RotationalDampingConstant d = 2 "Damping constant";
    parameter Modelica.Units.SI.Torque tau = 5 "Input torque";
    Modelica.Mechanics.Rotational.Components.Inertia shaft1(J = 1, phi(fixed = true, start = 0), w(start = 10, fixed = true)) annotation(Placement(transformation(extent = {{-70, -10}, {-50, 10}}, rotation = 0, origin = {0, 0}), visible = true));
    Modelica.Mechanics.Rotational.Sources.Torque torque(useSupport = true) annotation(Placement(transformation(extent = {{-100, -10}, {-80, 10}}, rotation = 0, origin = {0, 0}), visible = true));
    Modelica.Mechanics.Rotational.Components.Clutch clutch1(peak = 1.1, fn_max = 5) annotation(Placement(transformation(extent = {{-40, -10}, {-20, 10}}, rotation = 0, origin = {0, 0}), visible = true));
    Modelica.Blocks.Sources.Step stepInput2(startTime = T2) annotation(Placement(transformation(origin = {25, 35}, extent = {{-5, -5}, {15, 15}}, rotation = 270), visible = true));
    Modelica.Mechanics.Rotational.Components.Inertia shaft2(J = 1, phi(fixed = true, start = 0), w(fixed = true, start = 0)) annotation(Placement(transformation(extent = {{-10, -10}, {10, 10}}, rotation = 0, origin = {0, 0}), visible = true));
    Modelica.Mechanics.Rotational.Components.Clutch clutch2(peak = 1.1, fn_max = 5) annotation(Placement(transformation(extent = {{20, -10}, {40, 10}}, rotation = 0, origin = {0, 0}), visible = true));
    Modelica.Mechanics.Rotational.Components.Inertia shaft3(J = 1, phi(fixed = true, start = 0), w(fixed = true, start = 0)) annotation(Placement(transformation(extent = {{50, -10}, {70, 10}}, rotation = 0, origin = {0, 0}), visible = true));
    Modelica.Mechanics.Rotational.Components.Clutch clutch3(peak = 1.1, fn_max = 5) annotation(Placement(transformation(extent = {{80, -10}, {100, 10}}, rotation = 0, origin = {0, 0}), visible = true));
    Modelica.Mechanics.Rotational.Components.Inertia shaft4(J = 1, phi(fixed = true, start = 0), w(fixed = true, start = 0), stateSelect = StateSelect.always) annotation(Placement(transformation(extent = {{110, -10}, {130, 10}}, rotation = 0, origin = {0, 0}), visible = true));
    Modelica.Mechanics.Rotational.Components.Fixed fixed annotation(Placement(transformation(extent = {{-100, -30}, {-80, -10}}, rotation = 0, origin = {-20, -10}), visible = true));
    Modelica.Mechanics.Rotational.Components.Damper loadResistance(d = d) annotation(Placement(visible = true, transformation(origin = {0, -45}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Step stepInput1(startTime = T1, offset = 1, height = -1) annotation(Placement(transformation(origin = {-35, 35}, extent = {{-5, -5}, {15, 15}}, rotation = 270), visible = true));
    Modelica.Blocks.Sources.Constant referenceTorque(k = tau) annotation(Placement(visible = true, transformation(origin = {-120, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Step stepInput3(startTime = T3) annotation(Placement(transformation(origin = {85, 35}, extent = {{-5, -5}, {15, 15}}, rotation = 270), visible = true));
    Modelica.Mechanics.Rotational.Components.Damper couplingResistance(d = d) annotation(Placement(visible = true, transformation(origin = {-90, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(torque.flange, shaft1.flange_a) annotation(Line(points = {{-5, 0}, {5, 0}}, visible = true, color = {64, 64, 64}, origin = {-75, 0}));
    connect(shaft1.flange_b, clutch1.flange_a) annotation(Line(points = {{-5, 0}, {5, 0}}, visible = true, color = {64, 64, 64}, origin = {-45, 0}));
    connect(clutch1.flange_b, shaft2.flange_a) annotation(Line(points = {{-5, 0}, {5, 0}}, visible = true, color = {64, 64, 64}, origin = {-15, 0}));
    connect(shaft2.flange_b, clutch2.flange_a) annotation(Line(points = {{10, 0}, {10, 0}, {20, 0}}, visible = true, color = {64, 64, 64}));
    connect(clutch2.flange_b, shaft3.flange_a) annotation(Line(points = {{-5, 0}, {5, 0}}, visible = true, color = {64, 64, 64}, origin = {45, 0}));
    connect(shaft3.flange_b, clutch3.flange_a) annotation(Line(points = {{-5, 0}, {5, 0}}, visible = true, color = {64, 64, 64}, origin = {75, 0}));
    connect(clutch3.flange_b, shaft4.flange_a) annotation(Line(points = {{-5, 0}, {5, 0}}, visible = true, color = {64, 64, 64}, origin = {105, 0}));
    connect(stepInput2.y, clutch2.f_normalized) annotation(Line(points = {{30, 19}, {30, 19}, {30, 10}, {30, 11}}, color = {1, 37, 163}, visible = true));
    connect(fixed.flange, torque.support) annotation(Line(points = {{-110, -26.083}, {-110, -11.083}, {-90, -11.083}, {-90, -6.083}}, visible = true, color = {64, 64, 64}, origin = {0, -3.917}));
    connect(shaft4.flange_b, loadResistance.flange_b) annotation(Line(visible = true, origin = {105, -30}, points = {{25, 30}, {35, 30}, {35, -15}, {-95, -15}}, color = {64, 64, 64}));
    connect(loadResistance.flange_a, fixed.flange) annotation(Line(visible = true, origin = {-95, -30}, points = {{85, -15}, {-25, -15}, {-25, 0}, {-15, 0}}, color = {64, 64, 64}));
    connect(stepInput1.y, clutch1.f_normalized) annotation(Line(visible = true, origin = {-30, 15}, points = {{0, 4}, {0, -4}}, color = {1, 37, 163}));
    connect(referenceTorque.y, torque.tau) annotation(Line(visible = true, origin = {-105.5, 0}, points = {{-3.5, 0}, {3.5, 0}}, color = {1, 37, 163}));
    connect(stepInput3.y, clutch3.f_normalized) annotation(Line(visible = true, origin = {90, 15}, points = {{0, 4}, {0, -4}}, color = {1, 37, 163}));
    connect(couplingResistance.flange_b, shaft1.flange_a) annotation(Line(visible = true, origin = {-75, -15}, points = {{-5, -15}, {0, -15}, {0, 15}, {5, 15}}, color = {64, 64, 64}));
    connect(fixed.flange, couplingResistance.flange_a) annotation(Line(visible = true, origin = {-105, -30}, points = {{-5, 0}, {5, 0}}, color = {64, 64, 64}));
    annotation(experiment(StopTime = 20, __Wolfram_Algorithm = "cvodes", __Wolfram_SynchronizeWithRealTime = false), Documentation(info = "<html>


    <p>
By coupling clutches together, a variable structure drivetrain can be achieved. With different clutches engaged at different times, torque is supplied to different parts of the system.
</p>
    <h4>Simulation</h4>
    <p>
Simulating the model allows you to look at how the different shaft components behave over time, and how they are affected by each other. In order to properly analyze this model, it is recommended to use the Wolfram Language notebook that came with this model when it was downloaded.
</p><p>
To simulate the model in System Modeler, click the <span>Simulate</span> button <img src=\"modelica://CoupledClutches/DocumentationFiles/simulate.svg\" style=\"width:20px\" alt=\"simulate\" />.</p>
<p>
When the simulation is finished and Simulation Center has been opened, you can analyze the result by clicking the various states or Model Plots to the left of the Simulation Center window. For example, <span>AngularVelocities</span> shows the angular velocities of the shaft components over time, while <span>Clutch1EngagementVelocities</span> shows the relative velocities of the first and the second shaft components, as well as the force applied to the clutch between them.
</p><p>
To analyze the model based on a different parameter set than the default, select the state you want to edit in the Model Center and change the desired initial value under Parameters in the <span>General</span> tab. It can also be done directly from Simulation Center, under the <span>Parameters</span> tab. For examples, changing the <span>d</span> parameter will change the damping on the first and the last shaft components.
</p>

<p>In order to get the full experience of this example, you need a desktop Wolfram Language product. A free trial download is available at&nbsp;<a href=\"http://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></p>

<p>For the full example, open the accompanying notebook <a href=\"modelica://CoupledClutches.CoupledClutchesModel/CoupledClutches.nb\">CoupledClutches.nb</a>.</p>
</html>", figures = {Figure(title = "AngularVelocities", identifier = "26e14", preferred = true, plots = {Plot(curves = {Curve(y = shaft1.w, legend = "shaft 1"), Curve(y = shaft2.w, legend = "shaft 2"), Curve(y = shaft3.w, legend = "shaft 3"), Curve(y = shaft4.w, legend = "shaft 4")}, __Wolfram_markerAppearances = {MarkerAppearance(marker = "9bf31", labelPosition = LabelPosition(yOffsetCanvas = 0.293354943273906)), MarkerAppearance(marker = "d3d944", labelPosition = LabelPosition(yOffsetCanvas = 0.293354943273906)), MarkerAppearance(marker = "e4da3", labelPosition = LabelPosition(yOffsetCanvas = 0.2901134521880064)), MarkerAppearance(marker = "c4ca4", labelPosition = LabelPosition(yOffsetCanvas = 0.2901134521880065))})}, caption = "Angular velocities of the four shafts.", __Wolfram_markers = {Marker(identifier = "c4ca4", position = MarkerPosition(x = 1, xUnit = "s"), label = "only clutch 1 is engaged"), Marker(identifier = "e4da3", position = MarkerPosition(x = 5, xUnit = "s"), label = "clutch 2 is also engaged"), Marker(identifier = "d3d944", position = MarkerPosition(x = 10, xUnit = "s"), label = "clutch 3 is also engaged"), Marker(identifier = "9bf31", position = MarkerPosition(x = 15, xUnit = "s"), label = "clutch 1 is disengaged")}), Figure(title = "Clutch1EngagementVelocities", identifier = "8b754", plots = {Plot(curves = {Curve(y = shaft1.w, legend = "shaft 1"), Curve(y = shaft2.w, legend = "shaft 2")}, x = Axis(min = 0, max = 20, unit = "s"), y = Axis(min = -0.525, max = 10.5, unit = "rad/s"), __Wolfram_markerAppearances = {MarkerAppearance(marker = "31845"), MarkerAppearance(marker = "e4da3")}), Plot(curves = {Curve(y = clutch1.f_normalized, legend = "clutch 1 engagement")}, __Wolfram_markerAppearances = {MarkerAppearance(marker = "31845"), MarkerAppearance(marker = "e4da3")})}, caption = "Angular velocities of shaft 1 and shaft 2 at the end of the simulation are %{shaft1.w} and %{shaft2.w}.", __Wolfram_markers = {Marker(identifier = "e4da3", position = MarkerPosition(x = 5, xUnit = "s")), Marker(identifier = "31845", position = MarkerPosition(x = 5.738737768510577, xUnit = "s"))}, __Wolfram_intervals = {Interval(identifier = "b8226", startMarker = "e4da3", endMarker = "31845")}), Figure(title = "Clutch2EngagementVelocities", identifier = "37c00", plots = {Plot(curves = {Curve(y = shaft2.w, legend = "shaft 2"), Curve(y = shaft3.w, legend = "shaft 3")}), Plot(curves = {Curve(y = clutch2.f_normalized, legend = "clutch 2 engagement")})}, caption = "Angular velocities of shaft 2 and shaft 3 at the end of the simulation are %{shaft2.w} and %{shaft3.w}."), Figure(title = "Clutch3EngagementVelocities", identifier = "6edd3", plots = {Plot(curves = {Curve(y = shaft3.w, legend = "shaft 3"), Curve(y = shaft4.w, legend = "shaft 4")}), Plot(curves = {Curve(y = clutch3.f_normalized, legend = "clutch 3 engagement")})}, caption = "Angular velocities of shaft 3 and shaft 4  at the end of the simulation are %{shaft3.w} and %{shaft4.w}.")}), preferredView = "info", Diagram(coordinateSystem(extent = {{-145, -65}, {150, 47.487}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), __Wolfram);
  end CoupledClutchesModel;
  annotation(__Wolfram(openClass = CoupledClutches.CoupledClutchesModel), preferredView = "info", Documentation, uses(Modelica(version = "4.0.0")), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90.0, -90.0}, {90.0, 90.0}}, radius = 25), Text(visible = true, origin = {12.0, 20.8333}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-102.0, -70.8333}, {78.0, 29.1667}}, textString = "Ex", fontName = "Arial")}));
end CoupledClutches;
